/*  mainwindow.cpp
 *
 * --------------------------------------------- */

#include <QtGui>

#include "mainwindow.h"
#include "drawarea.h"


MainWindow::MainWindow()
{
    drawArea = new DrawArea;
    setCentralWidget(drawArea);

    createActions();
    createMenus();

    setWindowTitle(tr("Min Draw"));
    resize(400, 400);
}


void MainWindow::closeEvent(QCloseEvent *event)
{
    event->accept();
}


void MainWindow::about()
{
    QMessageBox::about(this, tr("About MinDraw"),
      tr("<p>The <b>MinDraw</b> example shows how to use QMainWindow as the "
         "base widget for an application.</p><p> We reimplement the paint "
         "event handler to update the application and the resize event handler "
         "to optimize  the application's appearance. In addition we reimplement "
         "the close event handler to intercept the close events before "
         "terminating the application.</p>"));
}


void MainWindow::createActions()
{
    exitAct = new QAction(tr("E&xit"), this);
    exitAct->setShortcut(tr("Ctrl+Q"));
    connect(exitAct, SIGNAL(triggered()), this, SLOT(close()));

    aboutAct = new QAction(tr("&About"), this);
    connect(aboutAct, SIGNAL(triggered()), this, SLOT(about()));

    aboutQtAct = new QAction(tr("About &Qt"), this);
    connect(aboutQtAct, SIGNAL(triggered()), qApp, SLOT(aboutQt()));
}


void MainWindow::createMenus()
{
    fileMenu = new QMenu(tr("&File"), this);
    fileMenu->addSeparator();
    fileMenu->addAction(exitAct);

    helpMenu = new QMenu(tr("&Help"), this);
    helpMenu->addAction(aboutAct);
    helpMenu->addAction(aboutQtAct);

    menuBar()->addMenu(fileMenu);
    menuBar()->addMenu(helpMenu);
}
